@@ -46,7 +46,7 @@ namespace Breeze
 
         //*@name property names
         //@{
-        static const char* const netWMShadowAtomName;
+        static const char netWMShadowAtomName[];
         //@}
 
         //* constructor
